#!/bin/sh
##########################################################################
## Copyright(c) 1997  Unicom Communications, Inc.
##
## Permission to use, copy, modify, and distribute this software and its
## documentation for commercial and non-commercial purposes is hereby
## granted provided that this copyright notice appears in all copies.
## Please refer to the file "LICENSE" for further copyright and licensing
## information.
##
## Unicom Communications, Inc. disclaims all warranties, whether express
## or implied, with respect to this software including, without limitation,
## any warranties of merchantability or fitness for a particular purpose
## or non-infringement. In no event shall Unicom Communications, Inc. be
## liable for any damages suffered by licensee as a result of using,
## modifying or distributing this software or its derivatives.
##########################################################################
##
## Servlet CGI launcher, specifically coded for the Netscape
## Enterprise 2.x+ CGI environment specification.
##
## There should be a file named 'java.env' in the local
## directory, which sets the following shell variables:
##
##   JAVAEXE    -- full path to the java executable
##   JAVAFLAGS  -- (optional) flags passed to the Java executable
##   JAVAMAIN   -- (optional) the java class containing main();
##                 defaults to unicom.servlet.cgi.CgiServletMain
##   
##########################################################################

## error()
##   Report an error to the clent.
##
error()
{
  /bin/echo "Status: $1"
  /bin/echo "Content-type: text/html"
  /bin/echo ""
  /bin/echo "<H1>" $2 "</H1>"
  exit 0
}


##
##  Establish the local java environment
##
if [ -r ./java.env ]; then
. ./java.env > /dev/null 2>&1
fi

if [ -z "$JAVAEXE" ]; then
  JAVAEXE=/usr/local/java/bin/sparc/green_threads/java
fi

if [ -z "$JAVAMAIN" ]; then
  JAVAMAIN="unicom.servlet.cgi.CgiServletMain"
fi

if [ -z "$JAVAFLAGS" ]; then
  JAVAFLAGS=""
fi


##
## Error check the environment
##
if [ ! -x "$JAVAEXE" ]; then
  error 500 "Error in Servlet CGI launcher"
fi


##
## Spawn the Java environment
##
exec ${JAVAEXE} \
  -Dhttp.SERVER_SOFTWARE="$SERVER_SOFTWARE" \
  -Dhttp.SERVER_NAME="$SERVER_NAME" \
  -Dhttp.SERVER_URL="$SERVER_URL" \
  -Dhttp.GATEWAY_INTERFACE="$GATEWAY_INTERFACE" \
  -Dhttp.SERVER_PROTOCOL="$SERVER_PROTOCOL" \
  -Dhttp.SERVER_PORT="$SERVER_PORT" \
  -Dhttp.REQUEST_METHOD="$REQUEST_METHOD" \
  -Dhttp.PATH_INFO="$PATH_INFO" \
  -Dhttp.PATH_TRANSLATED="$PATH_TRANSLATED" \
  -Dhttp.SCRIPT_NAME="$SCRIPT_NAME" \
  -Dhttp.QUERY_STRING="$QUERY_STRING" \
  -Dhttp.REMOTE_HOST="$REMOTE_HOST" \
  -Dhttp.REMOTE_ADDR="$REMOTE_ADDR" \
  -Dhttp.AUTH_TYPE="$AUTH_TYPE" \
  -Dhttp.REMOTE_USER="$REMOTE_USER" \
  -Dhttp.CONTENT_TYPE="$CONTENT_TYPE" \
  -Dhttp.CONTENT_LENGTH="$CONTENT_LENGTH" \
  -Dhttp.HTTPS="$HTTPS" \
  -Dhttp.HTTPS_KEYSIZE="$HTTPS_KEYSIZE" \
  -Dhttp.HTTPS_SECRETKEYSIZE="$HTTPS_SECRETKEYSIZE" \
  -Dhttp.HTTP_ACCEPT="$HTTP_ACCEPT" \
  -Dhttp.HTTP_ACCEPT_CHARSET="$HTTP_ACCEPT_CHARSET" \
  -Dhttp.HTTP_ACCEPT_ENCODING="$HTTP_ACCEPT_ENCODING" \
  -Dhttp.HTTP_ACCEPT_LANGUAGE="$HTTP_ACCEPT_LANGUAGE" \
  -Dhttp.HTTP_AUTHORIZATION="$HTTP_AUTHORIZATION"\
  -Dhttp.HTTP_COOKIE="$HTTP_COOKIE"\
  -Dhttp.HTTP_FROM="$HTTP_FROM" \
  -Dhttp.HTTP_HOST="$HTTP_HOST" \
  -Dhttp.HTTP_IF_MODIFIED_SINCE="$HTTP_IF_MODIFIED_SINCE" \
  -Dhttp.HTTP_IF_MATCH="$HTTP_IF_MATCH" \
  -Dhttp.HTTP_IF_NONE_MATCH="$HTTP_IF_NONE_MATCH" \
  -Dhttp.HTTP_IF_RANGE="$HTTP_IF_RANGE" \
  -Dhttp.HTTP_IF_UNMODIFIED_SINCE="$HTTP_IF_UNMODIFIED_SINCE" \
  -Dhttp.HTTP_MAX_FORWARDS="$HTTP_MAX_FORWARDS" \
  -Dhttp.HTTP_PROXY_AUTHORIZATION="$HTTP_PROXY_AUTHORIZATION" \
  -Dhttp.HTTP_RANGE="$HTTP_RANGE" \
  -Dhttp.HTTP_REFERER="$HTTP_REFERER" \
  -Dhttp.HTTP_USER_AGENT="$HTTP_USER_AGENT" \
  ${JAVAFLAGS} \
  ${JAVAMAIN}



