/*
 * Copyright(c) 1997  Unicom Communications, Inc.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for commercial and non-commercial purposes is hereby
 * granted provided that this copyright notice appears in all copies.
 * Please refer to the file "LICENSE" for further copyright and licensing
 * information.
 *
 * Unicom Communications, Inc. disclaims all warranties, whether express
 * or implied, with respect to this software including, without limitation,
 * any warranties of merchantability or fitness for a particular purpose
 * or non-infringement. In no event shall Unicom Communications, Inc. be
 * liable for any damages suffered by licensee as a result of using,
 * modifying or distributing this software or its derivatives.
 */


package unicom.servlet;
import java.io.*;
import javax.servlet.ServletInputStream;

/**
 * The Java Web Server development team for some reason chose to create
 * their own subclasses of InputStream and OutputStream for servlets.
 * Consequently, the Filter{Input|Output}Stream classes are not usable
 * with the Servlet API.<p>
 *
 * The ServletFilterInputStream class is an attempt to replicate the
 * functionality of the FilterInputStream class as a subclass of
 * the ServletInputStream.<p>
 *
 * @author   Eric Williams
 * @version  $Id: ServletFilterInputStream.java,v 1.3 1997/06/06 20:56:52 ericw Exp $
 */
public class ServletFilterInputStream extends ServletInputStream {

  /**
   * The input stream we are acting as a filter over.
   */
  protected InputStream in = null;

  /**
   * Construct a new filtered servlet input stream.
   * @param in the input stream
   */
  public ServletFilterInputStream(InputStream in) {
    this.in = in;
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public int read() throws IOException {
    return in.read();
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public int read(byte[] b) throws IOException {
    return in.read(b);
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public int read(byte[] b, int off, int len) throws IOException {
    return in.read(b, off, len);
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public long skip(long n) throws IOException {
    return in.skip(n);
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public int available() throws IOException {
    return in.available();
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public void close() throws IOException {
    in.close();
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public void mark(int readlimit) {
    in.mark(readlimit);
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public void reset() throws IOException {
    in.reset();
  }

  /**
   * Wrapper for the InputStream method of the same name.
   */
  public boolean markSupported() {
    return in.markSupported();
  }

}
