/*
 * Copyright(c) 1997  Unicom Communications, Inc.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for commercial and non-commercial purposes is hereby
 * granted provided that this copyright notice appears in all copies.
 * Please refer to the file "LICENSE" for further copyright and licensing
 * information.
 *
 * Unicom Communications, Inc. disclaims all warranties, whether express
 * or implied, with respect to this software including, without limitation,
 * any warranties of merchantability or fitness for a particular purpose
 * or non-infringement. In no event shall Unicom Communications, Inc. be
 * liable for any damages suffered by licensee as a result of using,
 * modifying or distributing this software or its derivatives.
 */


package unicom.servlet;
import java.io.*;
import javax.servlet.ServletOutputStream;

/**
 * The Java Web Server development team for some reason chose to create
 * their own subclasses of InputStream and OutputStream for servlets.
 * Consequently, the Filter{Input|Output}Stream classes are not usable
 * with the Servlet API.<p>
 *
 * The ServletFilterOutputStream class is an attempt to replicate the
 * functionality of the FilterOutputStream class as a subclass of
 * the ServletInputStream.<p>
 *
 * @author   Eric Williams
 * @version  $Id: ServletFilterOutputStream.java,v 1.3 1997/06/06 20:56:53 ericw Exp $
 */
public class ServletFilterOutputStream extends ServletOutputStream {

  /**
   * The output stream we are acting as a filter over.
   */
  OutputStream out = null;

  /**
   * Construct a new filtered servlet output stream.
   * @param out the output stream
   */
  public ServletFilterOutputStream(OutputStream out) {
    this.out = out;
  }

  /**
   * Wrapper for the OutputStream method of the same name.
   */
  public void write(int c) throws IOException {
    out.write(c);
  }

  /**
   * Wrapper for the OutputStream method of the same name.
   */
  public void write(byte[] b) throws IOException {
    out.write(b);
  }

  /**
   * Wrapper for the OutputStream method of the same name.
   */
  public void write(byte[] b, int off, int len) throws IOException {
    out.write(b, off, len);
  }

  /**
   * Wrapper for the OutputStream method of the same name.
   */
  public void flush() throws IOException {
    out.flush();
  }

  /**
   * Wrapper for the OutputStream method of the same name.
   */
  public void close() throws IOException {
    out.close();
  }

}
