/*
 * Copyright(c) 1997  Unicom Communications, Inc.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for commercial and non-commercial purposes is hereby
 * granted provided that this copyright notice appears in all copies.
 * Please refer to the file "LICENSE" for further copyright and licensing
 * information.
 *
 * Unicom Communications, Inc. disclaims all warranties, whether express
 * or implied, with respect to this software including, without limitation,
 * any warranties of merchantability or fitness for a particular purpose
 * or non-infringement. In no event shall Unicom Communications, Inc. be
 * liable for any damages suffered by licensee as a result of using,
 * modifying or distributing this software or its derivatives.
 */


package unicom.servlet.cgi;
import javax.servlet.*;
import java.util.*;
import java.text.*;
import java.io.*;

/**
 * An implementation of the ServletContext for servlets invoked through
 * CGI.  Many of the ServletContext methods are not yet implemented, and
 * will throw a NoSuchMethodError.  The log() method is implemented.
 *
 * @author   Eric Williams
 * @author   Matt Angell
 * @version  $Id: CgiServletContext.java,v 1.4 1997/06/06 20:56:54 ericw Exp $
 */
public class CgiServletContext implements ServletContext {

  /** file to log() messages to */
  protected String logFileName = null;

  /** The path to Server Root */
  private String serverRoot;

  /**
   * Create a ServletContext without any logging.
   */
  public CgiServletContext() {
  }

  /**
   * Create a ServletContext without logging to the specified file.
   */
  public CgiServletContext(String logFileName, String root) {
    this.logFileName = logFileName;
    this.serverRoot = root;
  }

  /**
   * @return the servlet with the specified name (not implemnted!)
   */
  public Servlet getServlet(String name) {
    return null;
  }

  /**
   * @return an enumeration of currently loaded servlets (not implemnted!)
   */
  public Enumeration getServlets() {
    return null;
  }

  /**
   * Log the specified message to the log file (if this CgiServletContext
   * was created with a valid log file name).
   * @param msg  message to log
   */
  public void log(String msg) {
    if (logFileName != null) {
      FileWriter wr = null;
      try {
	DateFormat df = new SimpleDateFormat("[dd/MMM/yyyy:HH:mm:ss]");
	df.setTimeZone(TimeZone.getDefault());

	wr = new FileWriter(logFileName, true /*append*/);
	wr.write(df.format(new Date())+" "
		 +msg+System.getProperty("line.separator"));
	wr.flush();
      } catch (IOException ex) {
	// don't do anything
      } finally {
	if (wr != null) {
	  try { wr.close(); } catch (IOException ex) { }
	}
      }
    }
  }

  /**
   * @param  vpath path to the server root
   * @return  the real path for the specified virtual path
   */
  public String getRealPath(String vpath) {
    return (serverRoot+"/"+vpath);
  }

  /**
   * not implemented.
   */
  public String getMimeType(String filename) {
    return null;
  }

  /**
   * @return basic info about this server
   */
  public String getServerInfo() {
    return "CGI Servlet Launcher 1.0";
  }

  /**
   * not implemented
   */
  public Object getAttribute(String key) {
    return null;
  }

}
