/*
 * Copyright(c) 1997  Unicom Communications, Inc.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for commercial and non-commercial purposes is hereby
 * granted provided that this copyright notice appears in all copies.
 * Please refer to the file "LICENSE" for further copyright and licensing
 * information.
 *
 * Unicom Communications, Inc. disclaims all warranties, whether express
 * or implied, with respect to this software including, without limitation,
 * any warranties of merchantability or fitness for a particular purpose
 * or non-infringement. In no event shall Unicom Communications, Inc. be
 * liable for any damages suffered by licensee as a result of using,
 * modifying or distributing this software or its derivatives.
 */


package unicom.servlet.cgi;
import java.io.*;
import java.util.*;

/**
 * Utility routines for the unicom.servlet.cgi package.<p>
 *
 * @author   Eric Williams
 * @version  $Id: CgiUtils.java,v 1.3 1997/06/06 20:56:58 ericw Exp $
 */
public class CgiUtils {

  /**
   * Add properties contained in the specified file into the Properties
   * object p.
   *
   * @param p  the existing properties object to add properties to
   * @param stringProperties  the properties to load, as a properties string
   */
  public static void loadProperties(Properties p, String stringProperties)
    throws IOException {
      InputStream in = null;
      try {
	in = new StringBufferInputStream(stringProperties);
	p.load(in);
      } finally {
	if (in != null) {
	  try { in.close(); } catch (IOException ex) { }
	}
      }
    }

  /**
   * Add properties contained in the specified file into the Properties
   * object p.
   *
   * @param p     the existing properties object to add properties to
   * @param file  the file to load into a Properties object
   */
  public static void loadProperties(Properties p, File file)
    throws IOException {
      InputStream in = null;
      try {
	in = new BufferedInputStream(new FileInputStream(file));
	p.load(in);
      } finally {
	if (in != null) {
	  try { in.close(); } catch (IOException ex) { }
	}
      }
    }

  /**
   * Construct a new Properties object from the specified input file.
   *
   * @param   filename the name of the file to load into a Properties object
   * @return  a new Properties object
   */
  public static Properties loadProperties(String filename)
    throws IOException {
      Properties p = new Properties();
      CgiUtils.loadProperties(p, filename);
      return p;
    }

  /**
   * Split the string 's' on any of the delimiter characters contained
   * in 'delim'.
   * @return  the original string, split into an array of strings (minus
   *  the delimiter characters)
   */
  public static String[] split(String s, String delim) {
    StringTokenizer st = new StringTokenizer(s, delim);
    String values[] = new String[st.countTokens()];
    for (int i=0; st.hasMoreTokens(); i++) {
      values[i] = st.nextToken();
    }
    return values;
  }


}
